@@ -1,6 +1,7 @@
 import re
 from sqlalchemy import types as sqltypes
 from sqlalchemy.dialects.postgresql.base import PGDialect
+from sqlalchemy.dialects.postgresql import INTERVAL
 from sqlalchemy.engine import reflection
 
 
@@ -14,6 +15,7 @@ class VerticaDialect(PGDialect):
     ischema_names = {
         'BINARY': sqltypes.BLOB,
         'VARBINARY': sqltypes.BLOB,
+        'LONG VARBINARY': sqltypes.BLOB,
         'BYTEA': sqltypes.BLOB,
         'RAW': sqltypes.BLOB,
 
@@ -21,6 +23,7 @@ class VerticaDialect(PGDialect):
 
         'CHAR': sqltypes.CHAR,
         'VARCHAR': sqltypes.VARCHAR,
+        'LONG VARCHAR': sqltypes.VARCHAR,
         'VARCHAR2': sqltypes.VARCHAR,
 
         'DATE': sqltypes.DATE,
@@ -32,8 +35,7 @@ class VerticaDialect(PGDialect):
         'TIMESTAMPTZ': sqltypes.TIMESTAMP(timezone=True),
         'TIMESTAMP WITH TIMEZONE': sqltypes.TIMESTAMP(timezone=True),
 
-        # Not supported yet
-        # INTERVAL
+        'INTERVAL': INTERVAL,
 
         # All the same internal representation
         'FLOAT': sqltypes.FLOAT,
@@ -190,7 +192,7 @@ class VerticaDialect(PGDialect):
         FROM v_catalog.columns
         where table_name = '{table_name}'
         {schema_conditional}
-        UNION ALL
+        UNION 
         SELECT
           column_name,
           data_type,
@@ -200,15 +202,49 @@ class VerticaDialect(PGDialect):
         where table_name = '{table_name}'
         {schema_conditional}
         """.format(table_name=table_name, schema_conditional=schema_conditional)
-        return [
-            {
-                'name': row.column_name,
-                'type': self.ischema_names[row.data_type.upper().split('(')[0]],
-                'nullable': row.is_nullable,
-                'default': row.column_default,
-                'primary_key': row.column_name in primary_key_columns
-            } for row in connection.execute(column_select)
-        ]
+        colobjs = []
+        for row in connection.execute(column_select):
+              colobj = self._get_column_info(
+                  row.column_name, 
+                  row.data_type, 
+                  row.is_nullable,
+                  row.column_default,
+                  (row.column_name in primary_key_columns)
+              )
+              if colobj:
+                  colobjs.append(colobj)
+        return colobjs
+
+    def _get_column_info(self, name, data_type, is_nullable, default, is_primary_key):
+        m = re.match(r'(\w+)(?:\((\d+)(?:,(\d+))?\))?', data_type)
+        if not m:
+            raise ValueError("data type string not parseable for type name and optional parameters: %s" % data_type)
+        typename = m.group(1).upper()
+        typeobj = self.ischema_names[typename]
+        typeargs = []
+        typekwargs = {}
+        for arg_group in (2, 3):
+            try:
+                param = m.group(arg_group)
+                if param:
+                    typeargs.append(int(param))
+            except (TypeError, ValueError):
+                pass
+
+        if any(tz_string in typename for tz_string in ('TIMEZONE', 'TIME ZONE', 'TIMESTAMPTZ')):
+            typekwargs['timezone'] = True
+
+        if callable(typeobj):
+            typeobj = typeobj(*typeargs, **typekwargs)
+
+        return {
+            'name': name,
+            'type': typeobj,
+            'nullable': is_nullable,
+            'default': default,
+            'primary_key': is_primary_key
+        } 
+
 
     @reflection.cache
     def get_unique_constraints(self, connection, table_name, schema=None, **kw):
